@@ -42,8 +42,8 @@
 #include "packages.h"
 #include "interface.h"
 #include "main.h"
-//#include "filesel.h"
 #include "filechooser.h"
+#include "feededit.h"
 
 #define N_(x) (x)
 
@@ -65,7 +65,7 @@
 #define HELPMESSAGE "GPE-Package\nVersion " VERSION \
 		"\nGPE frontend for ipkg\n\nflorian@handhelds.org"
 
-#define NOHELPMESSAGE N_("Displaying help failed.")
+#define NOHELPMESSAGE N_("Help for this application is not installed.")
 
 /* --- module global variables --- */
 
@@ -97,7 +97,7 @@ static GtkWidget *bApply;
 static GtkWidget *miUpdate, *miSysUpgrade, *miSelectLocal, *miApply;
 static GtkWidget *miFilterInst, *miFilterNotInst;
 static GtkWidget *sbar;
-static GtkWidget *fMain;
+GtkWidget *fMain;
 static GtkWidget *dlgAction = NULL;
 static GtkWidget *dlgInfo = NULL;
 static GtkTextBuffer *infobuffer = NULL;
@@ -123,7 +123,7 @@ static GtkItemFactoryEntry mMain_items[] = {
   { N_("/_File/s1"), NULL , NULL,    0, "<Separator>"},
   { N_("/File/_Close"),  NULL, do_safe_exit, MI_FILE_CLOSE, "<StockItem>", GTK_STOCK_QUIT },
   { N_("/_Packages"),         NULL,         NULL, MI_PACKAGES, "<Branch>" },
-  { N_("/Packages/Show _Installed"), "", on_tree_filter_changed, MI_FILTER_INST , "<CheckItem>"},
+  { N_("/Packages/Show Insta_lled"), "", on_tree_filter_changed, MI_FILTER_INST , "<CheckItem>"},
   { N_("/Packages/Show _Not Installed"), "", on_tree_filter_changed, MI_FILTER_NOTINST, "<CheckItem>"},
   { N_("/_Packages/s2"), NULL , NULL,    0, "<Separator>"},
   { N_("/Packages/Show _Info"), "<Control> I", on_package_info_clicked, MI_PACKAGES_INFO , "<Item>"},
@@ -181,9 +181,9 @@ gboolean dialog_destroy()
 void
 do_package_info(const char* name, const char *info)
 {
-	GtkWidget *sw;
-	GtkWidget *textview;
-	GtkTextBuffer *buffer;
+GtkWidget *sw;
+GtkWidget *textview;
+GtkTextBuffer *buffer;
 	
 	if (dlgInfo == NULL) {
 		dlgInfo = gtk_dialog_new_with_buttons(_("Package information"),GTK_WINDOW(fMain),
@@ -391,7 +391,6 @@ GtkTreeIter iter;
 	gtk_statusbar_push(GTK_STATUSBAR(sbar),
 		id,_("Updating views, please wait..."));
 	
-#warning improve this
 	gtk_tree_store_clear(GTK_TREE_STORE(store));
 	
 	for (i=0; i<pkg_count; i++) {
@@ -426,14 +425,14 @@ void on_tree_filter_changed(GtkCheckMenuItem *menuitem, gpointer user_data)
 
 void on_about_clicked (GtkWidget * w)
 {
-	show_message(GTK_MESSAGE_INFO,HELPMESSAGE);
+	show_message(GTK_MESSAGE_INFO, HELPMESSAGE);
 }
 
 
 void on_help_clicked (GtkWidget * w)
 {
 	if (gpe_show_help("gpe-package",NULL))
-		show_message(GTK_MESSAGE_ERROR, NOHELPMESSAGE);
+		show_message(GTK_MESSAGE_INFO, NOHELPMESSAGE);
 }
 
 
@@ -561,16 +560,13 @@ struct pollfd pfd[1];
 			do_message_dlg(GTK_MESSAGE_ERROR,_("Communication error, cannot continue."));
 			exit (1);
 		} else if (msg.type == PK_FRONT) {
-			// fprintf(stderr,"interf.: got type %d ctype %d\n", msg.type, msg.ctype);
 			switch (msg.ctype) {
 				case PK_QUESTION:
 					do_question(msg.content.tf.priority, msg.content.tf.str1);
 					break;
 				case PK_ERROR:
-					//do_message_dlg(GTK_MESSAGE_ERROR,msg.content.tf.str1);
 					if (!ErrorDialogOpen) {
 						GtkWidget *dialog;
-						//do_message_dlg(GTK_MESSAGE_ERROR, "Some error occured, please see log-tab");
 						dialog = gtk_message_dialog_new (GTK_WINDOW(fMain),
 		                                  GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
                 		                  GTK_MESSAGE_ERROR,
@@ -656,12 +652,11 @@ char *color;
 
 void do_local_install(char *filename,gpointer userdata)
 {
-	printf(filename);
 	if (!access(filename,F_OK)) {
 		send_message(PK_COMMAND,CMD_INSTALL,"",filename);
 		wait_command_finish();
 	} else {
-		do_message_dlg(GTK_MESSAGE_ERROR,
+		do_message_dlg(GTK_MESSAGE_WARNING,
 		_("The selected file could not be accessed."));
 	}
 }
@@ -672,7 +667,9 @@ void do_local_install(char *filename,gpointer userdata)
 int mainloop (int argc, char *argv[])
 {
 struct sockaddr_un name;
-	
+int opt;
+gboolean mode_upgrade = FALSE;
+
 	sleep(1); /* wait for second process to initialize */
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
@@ -682,6 +679,12 @@ struct sockaddr_un name;
 	signal (SIGINT, do_safe_exit);
 	signal (SIGTERM, do_safe_exit);
  	
+	while ((opt = getopt(argc, argv, "u")) > 0)
+	{
+		if (opt == 'u')
+			mode_upgrade = TRUE;
+	}
+
 	/* Create socket from which to read. */
 	sock = socket (AF_UNIX, SOCK_STREAM, 0);
 	if (sock < 0) {
@@ -706,8 +709,11 @@ struct sockaddr_un name;
 	create_fMain ();
 	gtk_widget_show (fMain);
   
-	/* get packages list */
-	send_message(PK_COMMAND,CMD_LIST,NULL,NULL);
+	/* do initial actions */
+	if (mode_upgrade)
+		on_system_update_clicked(NULL, NULL);
+	else
+		send_message(PK_COMMAND,CMD_LIST,NULL,NULL);
 	
 	gtk_timeout_add(500,get_pending_messages,NULL);
 	
@@ -730,7 +736,6 @@ int do_package_check(const char *package)
 
 void on_select_local(GtkButton *button, gpointer user_data)
 {
-	//ask_user_a_file("/tmp",_("Select package file"),do_local_install,NULL,NULL);
 	package_choose(fMain, do_local_install);
 }
 
@@ -752,8 +757,8 @@ char *name = NULL;
 
 void on_system_update_clicked(GtkButton *button, gpointer user_data)
 {
-GtkTextBuffer *logbuf;
-GtkTextIter start,end;
+	GtkTextBuffer *logbuf;
+	GtkTextIter start,end;
 	
 	gtk_widget_set_sensitive(miUpdate,FALSE);
 	gtk_widget_set_sensitive(miApply,FALSE);
@@ -762,6 +767,11 @@ GtkTextIter start,end;
 
 	error = 0;
 	
+	show_message(GTK_MESSAGE_INFO, 
+	             _("Make sure your internet connection is up " \ 
+	               "or your update source is available and " \
+	               "press OK to continue."));
+	
 	/* clear log */	
 	logbuf = gtk_text_view_get_buffer(GTK_TEXT_VIEW(txLog));
 	gtk_text_buffer_get_start_iter(GTK_TEXT_BUFFER(logbuf),&start);
@@ -909,7 +919,7 @@ char *tmp;
 	);
 
 	fMain = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title (GTK_WINDOW (fMain), _("GPE Package"));
+	gtk_window_set_title (GTK_WINDOW (fMain), _("Package Manager"));
 	gtk_window_set_default_size (GTK_WINDOW (fMain), 240, 300);
 	gtk_window_set_policy (GTK_WINDOW (fMain), TRUE, TRUE, FALSE);
 	gpe_set_window_icon(fMain, "icon");
@@ -1028,8 +1038,11 @@ char *tmp;
 	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(txLog),GTK_WRAP_WORD);
 	gtk_container_add(GTK_CONTAINER(cur),txLog);
 	gtk_box_pack_start(GTK_BOX(vbox),cur,TRUE,TRUE,0);	
-  
-	g_signal_connect(G_OBJECT (fMain),"destroy",gtk_main_quit,NULL);
+
+	cur = gtk_label_new(_("Feeds"));
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), create_feed_edit(), cur);
+
+	g_signal_connect(G_OBJECT (fMain), "destroy", gtk_main_quit, NULL);
   
 	gtk_widget_show_all(fMain);
 }
